@@ -1,3 +1,21 @@
+# Copyright 2015-2019 Venelin Mitov
+#
+# This file is part of POUMM.
+#
+# POUMM is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# POUMM is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with POUMM  If not, see <http://www.gnu.org/licenses/>.
+
+
 #' Summarize the results of a POUMM-fit
 #' 
 #' @param object a POUMM object returned by POUMM-function (see ?POUMM).
@@ -168,7 +186,7 @@ generateStatisticFunG0 <- function(object) {
           ll <- object$loglik(par, pruneInfo = object$pruneInfo)
           attr(ll, "g0")
         }), silent = TRUE)
-      if(class(g0s) == "try-error") {
+      if(inherits(g0s, "try-error")) {
         rep(NA_real_, nrow(par))
       } else {
         g0s
